@@ -6,7 +6,7 @@
 import unittest
 
 from gvm.errors import InvalidArgument
-from gvm.protocols.gmpv224 import CredentialType
+from gvm.protocols.gmp.requests.v224 import CredentialType
 
 
 class GetCredentialTypeFromStringTestCase(unittest.TestCase):
